pub enum CaptureRetention {
Head,
Tail,
HeadAndTail,
}Expand description
Which portions of an oversized captured stream are retained.
Variants
Head
Retain the beginning of the stream.
Tail
Retain the end of the stream.
HeadAndTail
Split the byte budget between the beginning and end of the stream.